@@ -2,19 +2,16 @@ Weka_control <-
 function(...)
 {
     rval <- list(...)
-    ## <FIXME>
-    ## Use nzchar() when 2.6.0 is required.
-    if((length(rval) > 0)
-       && (is.null(names(rval)) || !all(nchar(names(rval)) > 0)))
+    if((length(rval) > 0L)
+       && (is.null(names(rval)) || !all(nzchar(names(rval)))))
         stop("All arguments must be named.")
-    ## </FIXME>
     structure(rval, class = "Weka_control")
 }
 
 print.Weka_control <-
 function(x, ...)
 {
-    if(length(x) < 1) {
+    if(length(x) < 1L) {
         writeLines(gettext("An empty list of Weka control options."))
     } else {
         writeLines(gettextf("A list of Weka control options (%s):\n",
@@ -29,23 +26,21 @@ function(x, ...)
 as.character.Weka_control <-
 function(x, ...)
 {
-    if(!length(x)) return(character(0))
+    if(!length(x)) return(character())
 
-    ## <FIXME>
-    ## Use base::Map() when depending on R >= 2.6.0, but note that
-    ## (currently?) this has USE.NAMES = TRUE ...
+    ## <NOTE>
+    ## R 2.6.0 has base::Map(), but (currently?) this has
+    ## USE.NAMES = TRUE ...
     map <- function(f, ...)
         mapply(f, ..., SIMPLIFY = FALSE, USE.NAMES = FALSE)
-    ## </FIXME>
+    ## </NOTE>
 
     arg2char <- function(tag, val) {
         ## Works for a single (possibly empty) tag and a single value,
         ## which can be recursive, so that we can handle things like
         ##   Weka_control(K = list("RBFKernel", G = 2))
         ## <FIXME>
-        ## Use nzchar() when 2.6.0 is required.
-        tag <- if((nchar(tag) > 0)) paste("-", tag, sep = "") else NULL
-        ## </FIXME>
+        tag <- if(nzchar(tag)) paste("-", tag, sep = "") else NULL
         out <- if(is.list(val)) {
             nms <- names(val)
             if(is.null(nms)) nms <- character(length(val))
@@ -88,7 +83,7 @@ function(options, fun, ...)
         if(inherits(x, "Weka_control")) {
             ## New-style Weka control lists:
             ##   Weka_control(W = value)
-            ind <- which(names(x) %in% substring(options, 2))
+            ind <- which(names(x) %in% substring(options, 2L))
             if(any(ind)) x[ind] <- lapply(x[ind], fun, ...)
             ## Do *not* coerce to character so that we can compose
             ## several control handlers.
@@ -98,7 +93,7 @@ function(options, fun, ...)
             ##   c("-W", "J48")
             x <- as.character(x)        # Just making sure ...
             ind <- which(x %in% options)
-            if(any(ind)) x[ind + 1] <- sapply(x[ind + 1], fun, ...)
+            if(any(ind)) x[ind + 1L] <- sapply(x[ind + 1L], fun, ...)
         }
         x
     }
